@@ -402,7 +402,7 @@ class SelectConnectionDialog(gtk.Dialog):
         self.vbox.pack_start(pannable_area)
         self.action_area.show_all()
         self.vbox.show_all()
-        self.set_size_request(800,(vpn_manager.get_vpn_count()+1)*50+50)
+        self.set_size_request(800,vbox.size_request()[1]+10)
         #self.show_all()
 
 
@@ -418,11 +418,14 @@ class OpenvpnAppletSettings(gtk.Dialog):
         self.selection = None
         self.update_selection()
 
-        self.new_button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,"New")
+        self.new_button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.new_button.set_label("New")
         self.new_button.connect("clicked", self.open_new_dialog)
-        self.delete_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,"Delete")
+        self.delete_button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.delete_button.set_label("Delete")
         self.delete_button.connect("clicked", self.delete_clicked_event)
-        self.test_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL,"Test")
+        self.test_button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.test_button.set_label("Test")
         self.test_button.connect("clicked", self.test_clicked_event)
 
         self.selection.set_size_request(-1, 155)
@@ -671,7 +674,7 @@ class FileLinks(UserDict):
     def __init__(self, path, filetypes=None):
         UserDict.__init__(self)
         self.path = path
-        self.keywords = ["secret","up","down","ca","cert","key","pkcs12","iproute","status","dh","tls-verify","ipchange","client-connect","route-up","client-disconnect","learn-address","auth-user-pass-verify","askpass","auth-user-pass"]
+        self.keywords = ["secret","up","down","ca","cert","key","pkcs12","iproute","status","dh","tls-verify","ipchange","client-connect","route-up","client-disconnect","learn-address","auth-user-pass-verify","askpass","auth-user-pass","dh"]
         self.filetypes = filetypes
         self.matchword = {}
         self.files_not_found = []
@@ -707,7 +710,7 @@ class FileLinks(UserDict):
             if len(parts) > 0:
                 for word in self.keywords:
                     if parts[0] == word:
-                        print "MATCH: ", word
+                        log("MATCH: ", word)
                         #get filename
                         if len(parts) > 1:
                             filename = parts[1]
